Stroke

Struct Stroke 

pub struct Stroke {
    pub width: f32,
    pub color: Color32,
}
Describes the width and color of a line.

The default stroke is the same as Stroke::NONE.

Fields

width: f32color: Color32

Implementations

Source

impl Stroke

pub const NONE: Self

Same as Stroke::default.

pub fn new(width: impl Into<f32>, color: impl Into<Color32>) -> Self

pub fn is_empty(&self) -> bool

True if width is zero or color is transparent

pub fn round_center_to_pixel(&self, pixels_per_point: f32, coord: &mut f32)

For vertical or horizontal lines: round the stroke center to produce a sharp, pixel-aligned line.

pub(crate) fn round_rect_to_pixel(&self, pixels_per_point: f32, rect: &mut Rect)